% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/betaBinomial.R
\name{bb_resolve_scale}
\alias{bb_resolve_scale}
\title{Resolve a norm scale specification}
\usage{
bb_resolve_scale(scale)
}
\arguments{
\item{scale}{Either a character ("T", "IQ", "z", anything else = percentile)
or a numeric vector of length 2 with mean and sd.}
}
\value{
A numeric vector c(mean, sd); c(NA, NA) indicates percentile output.
}
\description{
Resolve a norm scale specification
}
\keyword{internal}
