% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/betaBinomial.R
\name{plot.cnormBetaBinomial2}
\alias{plot.cnormBetaBinomial2}
\title{Plot cnormBetaBinomial2 Model with Data and Percentile Lines}
\usage{
\method{plot}{cnormBetaBinomial2}(x, ...)
}
\arguments{
\item{x}{A fitted model object of class "cnormBetaBinomial" or
"cnormBetaBinomial2".}

\item{...}{Additional arguments passed to the plot method.
\itemize{
   \item age A vector of the age data.
   \item score A vector of the score data.
   \item weights An optional numeric vector of weights for each observation.
   \item percentiles An optional vector with the percentiles to plot.
   \item points Logical indicating whether to plot the data points.
     Default is TRUE.
   \item discrete Logical indicating whether to plot the exact discrete
     beta-binomial quantiles (TRUE, default) or a smooth continuous
     approximation via the underlying beta distribution (FALSE).
 }}
}
\value{
A ggplot object.
}
\description{
This function creates a visualization of a fitted cnormBetaBinomial2
model, including the original data points, manifest percentiles and
specified percentile lines. See \code{\link{plot.cnormBetaBinomial}}.
}
\seealso{
Other plot:
\code{\link[=compare]{compare()}},
\code{\link[=plot.cnorm]{plot.cnorm()}},
\code{\link[=plot.cnormBetaBinomial]{plot.cnormBetaBinomial()}},
\code{\link[=plotDensity]{plotDensity()}},
\code{\link[=plotDerivative]{plotDerivative()}},
\code{\link[=plotNorm]{plotNorm()}},
\code{\link[=plotNormCurves]{plotNormCurves()}},
\code{\link[=plotPercentileSeries]{plotPercentileSeries()}},
\code{\link[=plotPercentiles]{plotPercentiles()}},
\code{\link[=plotRaw]{plotRaw()}},
\code{\link[=plotSubset]{plotSubset()}}
}
\concept{plot}
