% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/betaBinomial.R
\name{predictCoefficients2}
\alias{predictCoefficients2}
\title{Predict alpha and beta parameters for a beta-binomial regression model}
\usage{
predictCoefficients2(model, ages, n = NULL)
}
\arguments{
\item{model}{An object of class "cnormBetaBinomial2".}

\item{ages}{A numeric vector of age points at which to make predictions.}

\item{n}{The maximum score to be achieved.}
}
\value{
A data frame with columns:
  \item{age}{The input age points}
  \item{a}{Predicted alpha values}
  \item{b}{Predicted beta values}
  \item{mu}{Predicted mean values}
  \item{sigma}{Predicted standard deviation values}
}
\description{
This function generates predictions from a fitted beta-binomial regression
model (mode 2) for new age points.
}
\details{
The function applies the same standardization used in model fitting and
the same clamping of the linear predictors (\eqn{\pm 20} on the log scale)
as the likelihood function, ensuring consistent behavior also under
(mild) extrapolation.
}
\keyword{internal}
