% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/betaBinomial.R
\name{bb_design_matrix}
\alias{bb_design_matrix}
\title{Build a raw polynomial design matrix with intercept}
\usage{
bb_design_matrix(x, degree)
}
\arguments{
\item{x}{A numeric vector.}

\item{degree}{Degree of the raw polynomial.}
}
\value{
A numeric matrix with columns 1, x, x^2, ..., x^degree.
}
\description{
Build a raw polynomial design matrix with intercept
}
\keyword{internal}
